@@ -1,3 +1,9 @@
+"""The built-in Socket Mode client
+
+* https://api.slack.com/apis/connections/socket
+* https://slack.dev/python-slack-sdk/socket-mode/
+
+"""
 import logging
 from concurrent.futures.thread import ThreadPoolExecutor
 from logging import Logger
@@ -14,7 +20,7 @@ from slack_sdk.socket_mode.request import SocketModeRequest
 from slack_sdk.web import WebClient
 from .connection import Connection, ConnectionState
 from ..interval_runner import IntervalRunner
-from ...errors import SlackClientConfigurationError
+from ...errors import SlackClientConfigurationError, SlackClientNotConnectedError
 from ...proxy_env_variable_loader import load_http_proxy_from_env
 
 
@@ -76,6 +82,25 @@ class SocketModeClient(BaseSocketModeClient):
         on_error_listeners: Optional[List[Callable[[Exception], None]]] = None,
         on_close_listeners: Optional[List[Callable[[int, Optional[str]], None]]] = None,
     ):
+        """Socket Mode client
+
+        Args:
+            app_token: App-level token
+            logger: Custom logger
+            web_client: Web API client
+            auto_reconnect_enabled: True if automatic reconnection is enabled (default: True)
+            trace_enabled: True if more detailed debug-logging is enabled (default: False)
+            all_message_trace_enabled: True if all message dump in debug logs is enabled (default: False)
+            ping_pong_trace_enabled: True if trace logging for all ping-pong communications is enabled (default: False)
+            ping_interval: interval for ping-pong with Slack servers (seconds)
+            receive_buffer_size: the chunk size of a single socket recv operation (default: 1024)
+            concurrency: the size of thread pool (default: 10)
+            proxy: the HTTP proxy URL
+            proxy_headers: additional HTTP header for proxy connection
+            on_message_listeners: listener functions for on_message
+            on_error_listeners: listener functions for on_error
+            on_close_listeners: listener functions for on_close
+        """
         self.app_token = app_token
         self.logger = logger or logging.getLogger(__name__)
         self.web_client = web_client or WebClient()
@@ -152,6 +177,7 @@ class SocketModeClient(BaseSocketModeClient):
             on_message_listener=self._on_message,
             on_error_listener=self._on_error,
             on_close_listener=self._on_close,
+            ssl_context=self.web_client.ssl,
         )
         current_session.connect()
 
@@ -181,7 +207,27 @@ class SocketModeClient(BaseSocketModeClient):
             self.logger.debug(
                 f"Sending a message (session id: {self.session_id()}, message: {message})"
             )
-        self.current_session.send(message)
+        try:
+            self.current_session.send(message)
+        except SlackClientNotConnectedError as e:
+            # We rarely get this exception while replacing the underlying WebSocket connections.
+            # We can do one more try here as the self.current_session should be ready now.
+            if self.logger.level <= logging.DEBUG:
+                self.logger.debug(
+                    f"Failed to send a message (session id: {self.session_id()}, error: {e}, message: {message})"
+                    " as the underlying connection was replaced. Retrying the same request only one time..."
+                )
+            # Although acquiring self.connect_operation_lock also for the first method call is the safest way,
+            # we avoid synchronizing a lot for better performance. That's why we are doing a retry here.
+            with self.connect_operation_lock:
+                if self.is_connected():
+                    self.current_session.send(message)
+                else:
+                    self.logger.warning(
+                        f"The current session (session id: {self.session_id()}) is no longer active. "
+                        "Failed to send a message"
+                    )
+                    raise e
 
     def close(self):
         self.closed = True
@@ -213,7 +259,7 @@ class SocketModeClient(BaseSocketModeClient):
             self.logger.debug(f"on_close invoked (session id: {self.session_id()})")
         if self.auto_reconnect_enabled:
             self.logger.info(
-                "Received CLOSE event. Going to reconnect... "
+                "Received CLOSE event. Reconnecting... "
                 f"(session id: {self.session_id()})"
             )
             self.connect_to_new_endpoint()
@@ -249,7 +295,7 @@ class SocketModeClient(BaseSocketModeClient):
                     self.current_session is None or not self.current_session.is_active()
                 ):
                     self.logger.info(
-                        "The session seems to be already closed. Going to reconnect... "
+                        "The session seems to be already closed. Reconnecting... "
                         f"(session id: {self.session_id()})"
                     )
                     self.connect_to_new_endpoint()
