@@ -508,19 +508,21 @@ class LegacyBaseClient:
                 return {"status": resp.code, "headers": resp.headers, "body": body}
             raise SlackRequestError(f"Invalid URL detected: {url}")
         except HTTPError as e:
-            resp = {"status": e.code, "headers": e.headers}
+            # As adding new values to HTTPError#headers can be ignored, building a new dict object here
+            response_headers = dict(e.headers.items())
+            resp = {"status": e.code, "headers": response_headers}
             if e.code == 429:
                 # for compatibility with aiohttp
                 if (
-                    "retry-after" not in resp["headers"]
-                    and "Retry-After" in resp["headers"]
+                    "retry-after" not in response_headers
+                    and "Retry-After" in response_headers
                 ):
-                    resp["headers"]["retry-after"] = resp["headers"]["Retry-After"]
+                    response_headers["retry-after"] = response_headers["Retry-After"]
                 if (
-                    "Retry-After" not in resp["headers"]
-                    and "retry-after" in resp["headers"]
+                    "Retry-After" not in response_headers
+                    and "retry-after" in response_headers
                 ):
-                    resp["headers"]["Retry-After"] = resp["headers"]["retry-after"]
+                    response_headers["Retry-After"] = response_headers["retry-after"]
 
             # read the response body here
             charset = e.headers.get_content_charset() or "utf-8"
